@@ -7,7 +7,7 @@ use DynaLoader ();
 
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 if($ENV{MOD_PERL}) {
     bootstrap Apache::Proxy $VERSION;
@@ -27,10 +27,11 @@ Apache::Proxy - Perl interface to mod_proxy
 =head1 DESCRIPTION
 
     my $status = Apache::Proxy->pass($r, "http://perl.apache.org/"); 
+    my $hashfile = Apache::Proxy->proxy_hash($r, $url);
 
 =head1 AUTHOR
 
-Doug MacEachern
+Doug MacEachern, Ilya Obshadko
 
 =head1 SEE ALSO
 
